Get a primary input row
Description
Retrieve a named primary-input row from a symmetric input–output table,
a use table, or a supply table (as returned by iotable_get()).
Usage
primary_input_get(data_table, primary_input = "compensation_employees")primary_input_get(data_table, primary_input = "compensation_employees")
Arguments
data_table |
A symmetric I–O table, use table, or supply table as
returned by |
primary_input |
Character. The primary input to return. Accepts common synonyms (e.g., "compensation of employees", "cfc", "taxes on production", "operating surplus", "imports"). |
Details
In I–O accounting, primary inputs (e.g., compensation of employees, consumption of fixed capital, taxes on production/subsidies, operating surplus/mixed income, and—when relevant—imports used for domestic production) are shown in the value-added block (third quadrant).
Value
A data frame containing the key column and the matching primary- input row.
References
Eurostat (2008). Eurostat Manual of Supply, Use and Input–Output Tables, ch. 13. United Nations (2018). Handbook on Supply and Use Tables and Input–Output Tables with Extensions and Applications (Rev. 1, “white cover”), ch. 10.
See Also
Other iotables processing functions:
conforming_vector_create(),
empty_remove(),
household_column_find(),
household_column_get(),
iotable_year_get(),
key_column_create(),
matrix_round(),
output_get(),
rows_add(),
supplementary_add(),
total_tax_add(),
vector_transpose_longer(),
vector_transpose_wider()
Examples
# Get the Germany 1995 demo SIOT with default labelling de_iot <- iotable_get(source = "germany_1995") # Select compensation of employees (row code: "compensation_employees") primary_input_get(de_iot, "compensation_employees") # Get the same table with Eurostat short labelling de_iot_short <- iotable_get(source = "germany_1995", labelling = "short") # Consumption of fixed capital (row code: "K1") primary_input_get(de_iot_short, "K1") # Operating surplus and mixed income, net (row code: "B2A3N") primary_input_get(de_iot_short, "B2A3N")# Get the Germany 1995 demo SIOT with default labelling de_iot <- iotable_get(source = "germany_1995") # Select compensation of employees (row code: "compensation_employees") primary_input_get(de_iot, "compensation_employees") # Get the same table with Eurostat short labelling de_iot_short <- iotable_get(source = "germany_1995", labelling = "short") # Consumption of fixed capital (row code: "K1") primary_input_get(de_iot_short, "K1") # Operating surplus and mixed income, net (row code: "B2A3N") primary_input_get(de_iot_short, "B2A3N")